@@ -1,6 +1,6 @@
 class TwitterSearchException(Exception):
 
-   # HTTP status codes are stored in TwitterSearch.exceptions
+   # HTTP status codes are stored in TwitterSearch.exceptions due to possible on-the-fly modifications
     _error_codes = { 
         1000 : 'Neither a list nor a string',
         1001 : 'Not a list object',
@@ -11,6 +11,12 @@ class TwitterSearchException(Exception):
         1006 : 'Invalid callback string',
         1007 : 'Not a date object',
         1008 : 'Invalid boolean',                
+        1009 : 'Invalid string',
+        1010 : 'Not a valid TwitterSearchOrder object',
+        1011 : 'No more results available',
+        1012 : 'No meta data available',
+        1013 : 'No tweets available',
+        1014 : 'No results available',
     }
 
     def __init__(self, code, msg = None):
